<?php
/**
 * SKT Bizness functions and definitions
 *
 * @package SKT Bizness
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'skt_bizness_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function skt_bizness_setup() {
	global $content_width; 
		if ( ! isset( $content_width ) ) {
    	$content_width = 810;
}

	load_theme_textdomain( 'skt-bizness', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_image_size('skt-bizness-homepage-thumb',240,145,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'skt-bizness' ),
		'footer' => __( 'Footer Menu', 'skt-bizness' ),
	) );
	add_theme_support( 'custom-background', array(
			  'default-color' => 'f1f0f0',
			  'default-image' => get_template_directory_uri().'/images/body_bg.jpg',
 ) );
	add_editor_style( 'editor-style.css' );
}
endif; // skt_bizness_setup
add_action( 'after_setup_theme', 'skt_bizness_setup' );


function skt_bizness_widgets_init() {    
	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'skt-bizness' ),
		'description'   => __( 'Appears on all site', 'skt-bizness' ),
		'id'            => 'sidebar-main',
		'before_widget' => '<aside class="sidebar-area"><div id="%1$s" class="custom-area %2$s">',
		'after_widget'  => '</div></aside>',
		'before_title'  => '<h3 class="widget_title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Header Widget', 'skt-bizness' ),
		'description'   => __( 'Appears on header of site', 'skt-bizness' ),
		'id'            => 'header',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Left Widget', 'skt-bizness' ),
		'description'   => __( 'Appears on footer of site', 'skt-bizness' ),
		'id'            => 'footer-left',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Right Widget', 'skt-bizness' ),
		'description'   => __( 'Appears on footer of site', 'skt-bizness' ),
		'id'            => 'footer-right',
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );

}
add_action( 'widgets_init', 'skt_bizness_widgets_init' );


function skt_bizness_scripts() {	
	wp_enqueue_style( 'skt_bizness-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'skt_bizness-editor-style', get_template_directory_uri()."/editor-style.css" );
	wp_enqueue_style( 'skt_bizness-responsive-style', get_template_directory_uri()."/css/theme-responsive.css" );
	wp_enqueue_style( 'skt_bizness-nivoslider-style', get_template_directory_uri()."/css/nivo-slider.css" );	
	wp_enqueue_style( 'skt_bizness-fontawesome-style', get_template_directory_uri()."/css/font-awesome.min.css" );
	wp_enqueue_style( 'skt_bizness-base-style', get_template_directory_uri()."/css/style_base.css" );
	wp_enqueue_script( 'skt_bizness-nivo-script', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'skt_bizness-custom_js', get_template_directory_uri() . '/js/custom.js' );	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'skt_bizness_scripts' );

function skt_bizness_ie_stylesheet(){
	global $wp_styles;
	
	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('skt-bizness-ie', get_template_directory_uri().'/css/ie.css', array('skt-bizness-style'));
	$wp_styles->add_data('skt-bizness-ie','conditional','IE');
	}
add_action('wp_enqueue_scripts','skt_bizness_ie_stylesheet');


function skt_bizness_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}

function skt_bizness_social($atts){
	 extract(shortcode_atts(array(
	  'icon' => '',
	  'link' => ''
	 ),$atts));
	  return '<a href="'.$link.'" target="_blank" class="fa fa-'.$icon.' fa-1x" title="'.$icon.'"></a>';
	 }
add_shortcode('social','skt_bizness_social');

// Define urls

define('SKT_URL','http://sktthemes.net/');
define('SKT_PRO_THEME_URL','http://www.sktthemes.net/themes/responsive-business-wordpress-theme/');
define('SKT_THEME_URL','http://www.sktthemes.net/themes/');
define('SKT_THEME_DOC','http://sktthemesdemo.net/documentation/bizness-documentation/');



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';


function skt_bizness_font_scripts() {
	wp_enqueue_style( 'skt-bizness-gfonts-textual', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('textual_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('body_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-tag', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('tag_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-contact', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('contact_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-navig', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('navigation_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-sldtitle', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('sldtitle_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-slddesc', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('slddesc_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-pgfont', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('page_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-wdgettitle', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('widgettitle_font')));
    wp_enqueue_style( 'skt-bizness-gfonts-pagelisting', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('pagelisting_font')));
	wp_enqueue_style( 'skt-bizness-gfonts-blogtitle', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('blogtitle_font')));
    wp_enqueue_style( 'skt-bizness-gfonts-footnav', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('footnav_font')));
 	wp_enqueue_style( 'skt-bizness-gfonts-copy', '//fonts.googleapis.com/css?family='.rawurlencode(get_theme_mod('copy_font')));
}

add_action( 'wp_enqueue_scripts', 'skt_bizness_font_scripts' );

function skt_bizness_nivo_set(){
	
	?>
    	<script>
			jQuery(document).ready(function() {
				jQuery('#slider').nivoSlider({
					effect:'<?php echo get_theme_mod('slider_effect','fade'); ?>',
					animSpeed: <?php echo get_theme_mod('anim_speed','500'); ?>,
					pauseTime: <?php echo get_theme_mod('pause_time','3000'); ?>,
					directionNav: <?php echo get_theme_mod('slide_nav','true'); ?>,
					controlNav: <?php echo get_theme_mod('slide_page','true'); ?>,
					pauseOnHover: <?php echo get_theme_mod('slide_pause','true'); ?>,
			});
		});
	</script>
    <?php
		
	}
add_action('wp_head','skt_bizness_nivo_set');



function skt_bizness_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}

function skt_bizness_custom_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'skt_bizness_custom_excerpt_length', 999 );
	
function skt_bizness_favicon(){
	if( get_theme_mod('favicon-set') != '')
	{
    	echo "<link rel='icon' type='image/x-icon' href=".get_theme_mod('favicon-set')." />";
    
	}
}
add_action('wp_head','skt_bizness_favicon');